/*
 * Copyright 2012 ETH Zuerich, CISD
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package ch.ethz.cisd.hotdeploy;

import java.util.LinkedHashSet;
import java.util.Set;

/**
 * A simple notifier for {@link PluginEvent}s.
 *
 * @author Bernd Rinn
 */
final class PluginEventNotifier
{
    private final Set<PluginEventListener> listeners = new LinkedHashSet<PluginEventListener>();
    
    public synchronized void addListener(PluginEventListener listener)
    {
        listeners.add(listener);
    }

    public synchronized void removeListener(PluginEventListener listener)
    {
        listeners.remove(listener);
    }
    
    synchronized void notifyListeners(PluginEvent event)
    {
        for (PluginEventListener listener : listeners)
        {
            listener.pluginChanged(event);
        }
    }

    synchronized void clear()
    {
        listeners.clear();
    }

}
